@@ -642,22 +642,8 @@ void bwlogbox(char *title, int width, ds_Tree *t, int display_mode)
     GtkWidget *ctext;
     GtkWidget *text;
     FILE *handle;
-    int lx;
-    int lx_module_line = 0;
-    int lx_module_line_locked = 0;
-    int lx_endmodule_line_locked = 0;
-
-    struct wave_logfile_lines_t *wlog_head=NULL, *wlog_curr=NULL;
-    int wlog_size = 0;
-    int line_no;
-    int s_line_find = -1, e_line_find = -1;
     struct logfile_context_t *ctx;
-    struct text_find_t *text_curr;
-
     char *default_text = t->filename;
-    char *design_unit = t->item;
-    int s_line = t->s_line;
-    int e_line = t->e_line;
 
     handle = fopen(default_text, "rb");
     if(!handle)
@@ -1468,8 +1454,11 @@ free_vars:
 }
 
 /*
- * $Id: logfile.c,v 1.4 2008/02/05 07:20:24 gtkwave Exp $
+ * $Id: logfile.c,v 1.5 2008/06/11 08:01:40 gtkwave Exp $
  * $Log: logfile.c,v $
+ * Revision 1.5  2008/06/11 08:01:40  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.4  2008/02/05 07:20:24  gtkwave
  * added realtime rtlbrowse updates (follows marker at 100ms intervals)
  *
