@@ -1,6 +1,8 @@
 #ifndef VLEX_DEFINES_H
 #define VLEX_DEFINES_H
 
+#include <stdlib.h>
+
 #define V_IGNORE (1)
 #define V_ID (2)
 #define V_PORT (3)
@@ -27,8 +29,11 @@ const char *is_builtin_define (register const char *str, register unsigned int l
 #endif
 
 /*
- * $Id: vlex.h,v 1.1.1.1 2007/05/30 04:25:38 gtkwave Exp $
+ * $Id: vlex.h,v 1.2 2007/09/23 18:33:53 gtkwave Exp $
  * $Log: vlex.h,v $
+ * Revision 1.2  2007/09/23 18:33:53  gtkwave
+ * warnings cleanups from sun compile
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:38  gtkwave
  * Imported sources
  *
