@@ -88,7 +88,8 @@ int i_bogus;
 
 
 enum PrimValues { PRIM_NUMBER, PRIM_SYMBOL, PRIM_SYMBIT, PRIM_SYMRANGE,
-			PRIM_CONCAT, PRIM_FUNC, PRIM_MINTYPMAX, PRIM_EXP 
+			PRIM_CONCAT, PRIM_FUNC, PRIM_MINTYPMAX, PRIM_EXP,
+			PRIM_NAMEDPARAM 
 		};
 
 struct i_primary
@@ -141,6 +142,12 @@ union
 		struct i_explist *args;
 		} funcall;
 
+	struct					/* named parameter */
+		{
+		struct i_symbol *sym;
+		struct i_primary *exp;		
+		} named_param;
+
 	} primval;
 };
 
@@ -166,8 +173,12 @@ void print_concat(struct i_primary *c, struct i_explist *e);
 #endif
 
 /*
- * $Id: inter.h,v 1.1.1.1 2007/05/30 04:25:52 gtkwave Exp $
+ * $Id: inter.h,v 1.2 2007/11/25 01:42:36 gtkwave Exp $
  * $Log: inter.h,v $
+ * Revision 1.2  2007/11/25 01:42:36  gtkwave
+ * added named parameter support to module instantiations in the vermin
+ * parser.  (this is a verilog 2001 feature.)
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:52  gtkwave
  * Imported sources
  *
