@@ -1031,6 +1031,15 @@ len = f->length;
 if((1)||(f->row <= 1)) /* sorry, arrays not supported yet in the viewer */
 	{
 	fprintf(stderr, "Import: %s\n", np->nname);
+	if(nr<1) nr=1;
+	if(!GLOBALS->ae2_lx2_table[txidx])
+		{
+	        GLOBALS->ae2_lx2_table[txidx] = calloc_2(nr, sizeof(struct lx2_entry));
+	        for(r=0;r<nr;r++)
+	                {
+	                GLOBALS->ae2_lx2_table[txidx][r].np = &np[r];
+	                }
+		}
 
 	aet2_rd_set_fac_process_mask(txidx);
 	ae2_iterator(GLOBALS->ae2_start_limit_cyc, GLOBALS->ae2_end_limit_cyc);
@@ -1042,9 +1051,9 @@ if((1)||(f->row <= 1)) /* sorry, arrays not supported yet in the viewer */
 	}
 
 
-if(nr<1) nr=1;
 for(r = 0; r < nr; r++)
 	{
+
 	histent_tail = htemp = histent_calloc();
 	if(len>1)
 		{
@@ -1086,6 +1095,23 @@ for(r = 0; r < nr; r++)
 		np[r].head.v.h_val = AN_X;	/* x */
 		}
 
+
+                {
+                struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+                htemp2->time = -1;  
+                if(len>1)
+                	{
+                        htemp2->v.h_vector = htemp->v.h_vector;
+                        }
+                        else
+                        {  
+                        htemp2->v.h_val = htemp->v.h_val;
+                        }
+		htemp2->next = htemp;
+                htemp = htemp2;
+                GLOBALS->ae2_lx2_table[txidx][r].numtrans++;
+                }
+
 	np[r].head.time  = -2;
 	np[r].head.next = htemp;
 	np[r].numhist=GLOBALS->ae2_lx2_table[txidx][r].numtrans +2 /*endcap*/ +1 /*frontcap*/;
@@ -1194,6 +1220,23 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 				htemp = GLOBALS->ae2_lx2_table[txidx][r].histent_head;
 				}
 
+
+                        {
+                        struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+                        htemp2->time = -1;  
+                        if(len>1)
+                                {
+                                htemp2->v.h_vector = htemp->v.h_vector;
+                                }
+                                else
+                                {  
+                                htemp2->v.h_val = htemp->v.h_val;
+                                }
+                        htemp2->next = htemp;
+                        htemp = htemp2;
+                        GLOBALS->ae2_lx2_table[txidx][r].numtrans++;
+                        }
+
 			if(len>1)
 				{
 				np->head.v.h_vector = (char *)malloc_2(len);
@@ -1222,8 +1265,11 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 /* ...of AET2_IS_PRESENT */
 
 /*
- * $Id: ae2.c,v 1.6 2008/02/19 22:00:28 gtkwave Exp $
+ * $Id: ae2.c,v 1.7 2008/06/17 18:03:45 gtkwave Exp $
  * $Log: ae2.c,v $
+ * Revision 1.7  2008/06/17 18:03:45  gtkwave
+ * added time = -1 endcaps
+ *
  * Revision 1.6  2008/02/19 22:00:28  gtkwave
  * added aetinfo support
  *
