@@ -17,6 +17,8 @@
 #include "lx2.h"
 
 #define AET2_RDLOAD "AE2LOAD | "
+#define AET2_TIMEFAC "AE2(!!TIME!!)"
+#define AET2_PRECFAC "AE2(!!PREC!!)"
 
 struct ae2_ncycle_autosort
 {
@@ -82,8 +84,11 @@ uint64_t 	ae2_read_ith_sparse_row(AE2_HANDLE handle, unsigned long symbol_idx, u
 #endif
 
 /*
- * $Id: ae2.h,v 1.4 2007/08/31 22:42:43 gtkwave Exp $
+ * $Id: ae2.h,v 1.5 2008/02/19 22:00:28 gtkwave Exp $
  * $Log: ae2.h,v $
+ * Revision 1.5  2008/02/19 22:00:28  gtkwave
+ * added aetinfo support
+ *
  * Revision 1.4  2007/08/31 22:42:43  gtkwave
  * 3.1.0 RC3 updates
  *
