@@ -28,12 +28,13 @@
 #include "main.h"
 #include "menu.h"
 #include "busy.h"
+#include "hierpack.h"
 #include <stdlib.h>
 
 /*
  * attempt to match top vs bottom rather than emit <Vector>
  */
-char *attempt_vecmatch(char *s1, char *s2)
+char *attempt_vecmatch_2(char *s1, char *s2)
 {
 char *s;
 char *p1, *p2;
@@ -47,8 +48,6 @@ int sfxlen = 0;
 int totlen;
 int idx;
 
-if((!s1)||(!*s1)||(!s2)||(!*s2)) return(NULL);
-
 if(!strcmp(s1, s2)) { s = malloc_2(strlen(s1)+1); strcpy(s, s1); return(s); }
 
 p1 = s1; p2 = s2;
@@ -147,16 +146,22 @@ totlen = pfxlen + 1 + n1len + 1 + n2len + 1 + sfxlen + 1;
 s = malloc_2(totlen);
 memcpy(s, s1, pfxlen);
 idx = pfxlen;
-s[idx] = '[';
-idx++;
+if(!(pfxlen && (s1[pfxlen-1]=='[')))
+	{
+	s[idx] = '[';
+	idx++;
+	}
 memcpy(s+idx, n1, n1len);
 idx += n1len;
 s[idx] = ':';
 idx++;
 memcpy(s+idx, n2, n2len);
 idx += n2len;
-s[idx] = ']';
-idx++;
+if(*sfx != ']')
+	{
+	s[idx] = ']';
+	idx++;
+	}
 if(sfxlen) { memcpy(s+idx, sfx, sfxlen); idx+=sfxlen; }
 s[idx] = 0;
 
@@ -164,6 +169,31 @@ return(s);
 }
 
 
+char *attempt_vecmatch(char *s1, char *s2)
+{
+char *pnt;
+
+if((!s1)||(!*s1)||(!s2)||(!*s2)) 
+	{
+	return(NULL);
+	}
+	else
+	{
+	int ns1_was_decompressed;
+	char *ns1 = hier_decompress_flagged(s1, &ns1_was_decompressed);
+	int ns2_was_decompressed;
+	char *ns2 = hier_decompress_flagged(s2, &ns2_was_decompressed);
+
+	pnt = attempt_vecmatch_2(ns1, ns2);
+
+	if(ns1_was_decompressed) free_2(ns1);
+	if(ns2_was_decompressed) free_2(ns2);
+
+	return(pnt);
+	}
+}
+
+
 /*
  * mvlfac resolution
  */
@@ -1438,6 +1468,7 @@ struct symbol *symhi = NULL, *symlo = NULL;
 char hier_delimeter2;
 char *name=NULL;
 char *s1, *s2;
+int s1_was_packed, s2_was_packed;
 int root1len=0, root2len=0;
 int l1, l2;
 
@@ -1470,8 +1501,8 @@ if(!GLOBALS->autocoalesce_reversal)		/* normal case for MTI */
 	}
 
 
-s1=symhi->n->nname;
-s2=symlo->n->nname;
+s1=hier_decompress_flagged(symhi->n->nname, &s1_was_packed);
+s2=hier_decompress_flagged(symlo->n->nname, &s2_was_packed);
 		
 l1=strlen(s1); 
 
@@ -1570,6 +1601,9 @@ if((root1len!=root2len)||(!root1len)||(!root2len)||
 		}
 	}
 
+if(s1_was_packed) { free_2(s1); }
+if(s2_was_packed) { free_2(s2); }
+
 return(name);
 }
 
@@ -2825,8 +2859,14 @@ return(made);
 /****************/
 
 /*
- * $Id: bitvec.c,v 1.4 2007/09/23 18:33:53 gtkwave Exp $
+ * $Id: bitvec.c,v 1.6 2008/07/18 19:54:56 gtkwave Exp $
  * $Log: bitvec.c,v $
+ * Revision 1.6  2008/07/18 19:54:56  gtkwave
+ * hierpack and vecmatch fixes with removal of extra brackets
+ *
+ * Revision 1.5  2008/07/18 19:37:00  gtkwave
+ * hierpack fix for makename
+ *
  * Revision 1.4  2007/09/23 18:33:53  gtkwave
  * warnings cleanups from sun compile
  *
