@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2007.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,20 +14,25 @@
 #include "symbol.h"
 
 static char *time_prefix=" munpf";
+
 static char *maxtime_label_text="Maximum Time";
 static char *marker_label_text ="Marker Time";
 
+static char *maxtime_label_text_hpos="Max";
+static char *marker_label_text_hpos ="Marker";
 
 void update_maxmarker_labels(void)
 {
 if(GLOBALS->use_maxtime_display) 
 	{
-	gtk_label_set(GTK_LABEL(GLOBALS->max_or_marker_label_currenttime_c_1),maxtime_label_text);
+	gtk_label_set(GTK_LABEL(GLOBALS->max_or_marker_label_currenttime_c_1),
+		(!GLOBALS->use_toolbutton_interface) ? maxtime_label_text : maxtime_label_text_hpos);
 	update_maxtime(GLOBALS->max_time);
 	}
 	else
 	{
-	gtk_label_set(GTK_LABEL(GLOBALS->max_or_marker_label_currenttime_c_1),marker_label_text);
+	gtk_label_set(GTK_LABEL(GLOBALS->max_or_marker_label_currenttime_c_1),
+		(!GLOBALS->use_toolbutton_interface) ? marker_label_text : marker_label_text_hpos);
 	update_markertime(GLOBALS->tims.marker);
 	}
 }
@@ -174,7 +179,17 @@ if(GLOBALS->anno_ctx)
 	if(val >= 0)
 		{
 		GLOBALS->anno_ctx->marker_set = 0;	/* avoid race on update */
-		GLOBALS->anno_ctx->marker = val / GLOBALS->time_scale;
+
+		if(!GLOBALS->ae2_time_xlate)
+			{
+			GLOBALS->anno_ctx->marker = val / GLOBALS->time_scale;
+			}
+			else
+			{
+			int rvs_xlate = bsearch_aetinfo_timechain(val);
+			GLOBALS->anno_ctx->marker = ((TimeType)rvs_xlate) + GLOBALS->ae2_start_cyc;
+			}
+
 		reformat_time(GLOBALS->anno_ctx->time_string, val, GLOBALS->time_dimension);
 
 		GLOBALS->anno_ctx->marker_set = 1;
@@ -258,12 +273,12 @@ void update_basetime(TimeType val)
 {
 if(val>=0)
 	{
-	gtk_label_set(GTK_LABEL(GLOBALS->base_or_curtime_label_currenttime_c_1), "Base Marker");
+	gtk_label_set(GTK_LABEL(GLOBALS->base_or_curtime_label_currenttime_c_1), (!GLOBALS->use_toolbutton_interface) ? "Base Marker" : "Base");
 	reformat_time(GLOBALS->curtext_currenttime_c_1, val, GLOBALS->time_dimension);
 	}
 	else
 	{
-	gtk_label_set(GTK_LABEL(GLOBALS->base_or_curtime_label_currenttime_c_1), "Current Time");
+	gtk_label_set(GTK_LABEL(GLOBALS->base_or_curtime_label_currenttime_c_1), (!GLOBALS->use_toolbutton_interface) ? "Current Time" : "Cursor");
 	reformat_time_blackout(GLOBALS->curtext_currenttime_c_1, GLOBALS->cached_currenttimeval_currenttime_c_1, GLOBALS->time_dimension);
 	}
 
@@ -304,8 +319,8 @@ GtkWidget *mainbox;
 GtkWidget *eventbox;
 
 GLOBALS->max_or_marker_label_currenttime_c_1=(GLOBALS->use_maxtime_display)
-	? gtk_label_new(maxtime_label_text)
-	: gtk_label_new(marker_label_text);
+	? gtk_label_new((!GLOBALS->use_toolbutton_interface) ? maxtime_label_text : maxtime_label_text_hpos)
+	: gtk_label_new((!GLOBALS->use_toolbutton_interface) ? marker_label_text : marker_label_text_hpos);
 
 GLOBALS->maxtext_currenttime_c_1=(char *)malloc_2(40);
 if(GLOBALS->use_maxtime_display)
@@ -322,31 +337,70 @@ GLOBALS->maxtimewid_currenttime_c_1=gtk_label_new(GLOBALS->maxtext_currenttime_c
 GLOBALS->curtext_currenttime_c_1=(char *)malloc_2(40);
 if(GLOBALS->tims.baseline<0)
 	{
-	GLOBALS->base_or_curtime_label_currenttime_c_1=gtk_label_new("Current Time");
+	GLOBALS->base_or_curtime_label_currenttime_c_1=gtk_label_new((!GLOBALS->use_toolbutton_interface) ? "Current Time" : "Cursor");
 	reformat_time(GLOBALS->curtext_currenttime_c_1, (GLOBALS->currenttime=GLOBALS->min_time), GLOBALS->time_dimension);
 	GLOBALS->curtimewid_currenttime_c_1=gtk_label_new(GLOBALS->curtext_currenttime_c_1);
 	}
 	else
 	{
-	GLOBALS->base_or_curtime_label_currenttime_c_1=gtk_label_new("Base Marker");
+	GLOBALS->base_or_curtime_label_currenttime_c_1=gtk_label_new((!GLOBALS->use_toolbutton_interface) ? "Base Marker" : "Base");
 	reformat_time(GLOBALS->curtext_currenttime_c_1, GLOBALS->tims.baseline, GLOBALS->time_dimension);
 	GLOBALS->curtimewid_currenttime_c_1=gtk_label_new(GLOBALS->curtext_currenttime_c_1);
 	}
 
-mainbox=gtk_vbox_new(FALSE, 0);
+if(!GLOBALS->use_toolbutton_interface)
+	{
+	mainbox=gtk_vbox_new(FALSE, 0);
+	}
+	else
+	{
+	mainbox=gtk_hbox_new(FALSE, 0);
+	}
+
+gtk_widget_show(mainbox);   
 eventbox=gtk_event_box_new();
 gtk_container_add(GTK_CONTAINER(eventbox), mainbox);
 
-gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->max_or_marker_label_currenttime_c_1, TRUE, FALSE, 0);
-gtk_widget_show(GLOBALS->max_or_marker_label_currenttime_c_1);
-gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->maxtimewid_currenttime_c_1, TRUE, FALSE, 0);
-gtk_widget_show(GLOBALS->maxtimewid_currenttime_c_1);
+if(!GLOBALS->use_toolbutton_interface)
+	{
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->max_or_marker_label_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->max_or_marker_label_currenttime_c_1);
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->maxtimewid_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->maxtimewid_currenttime_c_1);
 
-gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->base_or_curtime_label_currenttime_c_1, TRUE, FALSE, 0);
-gtk_widget_show(GLOBALS->base_or_curtime_label_currenttime_c_1);
-gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->curtimewid_currenttime_c_1, TRUE, FALSE, 0);
-gtk_widget_show(GLOBALS->curtimewid_currenttime_c_1);
-gtk_widget_show(mainbox);   
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->base_or_curtime_label_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->base_or_curtime_label_currenttime_c_1);
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->curtimewid_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->curtimewid_currenttime_c_1);
+	}
+	else
+	{
+	GtkWidget *dummy;
+
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->max_or_marker_label_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->max_or_marker_label_currenttime_c_1);
+
+        dummy=gtk_label_new(": ");
+        gtk_widget_show (dummy);
+	gtk_box_pack_start(GTK_BOX(mainbox), dummy, TRUE, FALSE, 0);
+
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->maxtimewid_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->maxtimewid_currenttime_c_1);
+
+        dummy=gtk_label_new("  |  ");
+        gtk_widget_show (dummy);
+	gtk_box_pack_start(GTK_BOX(mainbox), dummy, TRUE, FALSE, 0);
+
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->base_or_curtime_label_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->base_or_curtime_label_currenttime_c_1);
+
+        dummy=gtk_label_new(": ");
+        gtk_widget_show (dummy);
+	gtk_box_pack_start(GTK_BOX(mainbox), dummy, TRUE, FALSE, 0);
+
+	gtk_box_pack_start(GTK_BOX(mainbox), GLOBALS->curtimewid_currenttime_c_1, TRUE, FALSE, 0);
+	gtk_widget_show(GLOBALS->curtimewid_currenttime_c_1);
+	}
 
 return(eventbox);
 }
@@ -418,8 +472,23 @@ switch(scale)
 }
 
 /*
- * $Id: currenttime.c,v 1.2 2007/08/26 21:35:40 gtkwave Exp $
+ * $Id: currenttime.c,v 1.7 2008/02/19 22:56:11 gtkwave Exp $
  * $Log: currenttime.c,v $
+ * Revision 1.7  2008/02/19 22:56:11  gtkwave
+ * rtlbrowse update to handle aet time substitutions
+ *
+ * Revision 1.6  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.5  2008/01/09 08:47:10  gtkwave
+ * renamed status strings to gtkwave-2 style
+ *
+ * Revision 1.4  2008/01/09 08:26:16  gtkwave
+ * added shorter labels when in horizontal toolbuttons mode
+ *
+ * Revision 1.3  2008/01/08 23:03:35  gtkwave
+ * added toolbar using use_toolbutton_interface rc variable
+ *
  * Revision 1.2  2007/08/26 21:35:40  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
