@@ -479,10 +479,6 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 void
 service_left_edge(GtkWidget *text, gpointer data)
 {
-GtkAdjustment *hadj;
-gfloat inc;
-TimeType ntinc;
-
 if(GLOBALS->helpbox_is_active)
         {
         help_text_bold("\n\nFind Next Edge Left");
@@ -501,10 +497,6 @@ DEBUG(printf("Edge Left\n"));
 void
 service_right_edge(GtkWidget *text, gpointer data)
 {
-GtkAdjustment *hadj;
-gfloat inc;
-TimeType ntinc, pageinc;
-
 if(GLOBALS->helpbox_is_active)
         {
         help_text_bold("\n\nFind Next Edge Right");
@@ -581,8 +573,11 @@ return(table);
 }
    
 /*
- * $Id: edgebuttons.c,v 1.5 2008/05/01 02:53:37 gtkwave Exp $
+ * $Id: edgebuttons.c,v 1.6 2008/06/11 08:01:48 gtkwave Exp $
  * $Log: edgebuttons.c,v $
+ * Revision 1.6  2008/06/11 08:01:48  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.5  2008/05/01 02:53:37  gtkwave
  * edgebutton fix (went back two edges on a concat vector instead of one)
  *
