@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef FGET_DYNAMIC_H
 #define FGET_DYNAMIC_H
 
@@ -15,13 +17,23 @@
 char *fgetmalloc(FILE *handle);
 char *fgetmalloc_stripspaces(FILE *handle);
 
-extern int fgetmalloc_len;
-
 #endif
 
 /*
- * $Id: fgetdynamic.h,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: fgetdynamic.h,v 1.2 2007/08/26 21:35:40 gtkwave Exp $
  * $Log: fgetdynamic.h,v $
+ * Revision 1.2  2007/08/26 21:35:40  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:45  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:19  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:22  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
