@@ -26,9 +26,21 @@
 
 #if HAVE_STDINT_H
 #include <stdint.h>
+#if __WORDSIZE == 64
+	#define GHWLLD "%ld"
+#else
+	#define GHWLLD "%lld"
+#endif
 #endif
 #if HAVE_INTTYPES_H
 #include <inttypes.h>
+#ifndef GHWLLD
+#if __WORDSIZE == 64
+	#define GHWLLD "%ld"
+#else
+	#define GHWLLD "%lld"
+#endif
+#endif
 #endif
 
 enum ghdl_rtik {
@@ -405,8 +417,11 @@ void ghw_disp_types (struct ghw_handler *h);
 #endif /* _GHWLIB_H_ */
 
 /*
- * $Id: ghwlib.h,v 1.2 2007/08/26 21:35:41 gtkwave Exp $
+ * $Id: ghwlib.h,v 1.3 2008/07/01 18:51:06 gtkwave Exp $
  * $Log: ghwlib.h,v $
+ * Revision 1.3  2008/07/01 18:51:06  gtkwave
+ * compiler warning fixes for amd64
+ *
  * Revision 1.2  2007/08/26 21:35:41  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
