@@ -827,6 +827,14 @@ NULL, /* dnd_sigview */
 /*
  * vcd.c
  */
+0, /* do_hier_compress */
+NULL, /* hier_pfx */
+0, /* hier_pfx_cnt */
+NULL, /* prev_hier_pfx */
+0, /* prev_hier_pfx_len */
+0, /* prev_hier_pfx_cnt */
+NULL, /* pfx_hier_array */
+NULL, /* prev_hier_uncompressed_name */
 NULL, /* vcd_jmp_buf */
 -1, /* vcd_warning_filesize 472 */
 1, /* autocoalesce 473 */
@@ -1177,12 +1185,11 @@ void reload_into_new_context(void)
 {
  FILE *statefile;
  struct Global *new_globals, *setjmp_globals;
- int i;
  gint tree_frame_x = -1, tree_frame_y = -1;
  gdouble tree_vadj_value = 0.0;
  gdouble tree_hadj_value = 0.0;
  int fix_from_time = 0, fix_to_time = 0;
- TimeType from_time, to_time;
+ TimeType from_time = LLDescriptor(0), to_time = LLDescriptor(0);
  char timestr[32];
  struct stringchain_t *hier_head = NULL, *hier_curr = NULL;
  int load_was_success = 0;
@@ -1446,6 +1453,7 @@ void reload_into_new_context(void)
  new_globals->convert_to_reals = GLOBALS->convert_to_reals;
  new_globals->disable_mouseover = GLOBALS->disable_mouseover;
  new_globals->disable_tooltips = GLOBALS->disable_tooltips;
+ new_globals->do_hier_compress = GLOBALS->do_hier_compress;
  new_globals->do_initial_zoom_fit = GLOBALS->do_initial_zoom_fit;
  new_globals->do_resize_signals = GLOBALS->do_resize_signals;
  new_globals->enable_fast_exit = GLOBALS->enable_fast_exit;
@@ -1497,6 +1505,10 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->fontname_signals, &GLOBALS->fontname_signals); 
  strcpy2_into_new_context(new_globals, &new_globals->fontname_waves, &GLOBALS->fontname_waves);
 
+ /* hierarchy handling from vcd.c */
+ if(GLOBALS->hier_pfx) { jrb_free_tree(GLOBALS->hier_pfx); GLOBALS->hier_pfx = NULL; }
+
+
  /* vlist.c */
  if(GLOBALS->vlist_handle)
 	{
@@ -1591,6 +1603,7 @@ void reload_into_new_context(void)
 #endif
 	break;
   
+   case NO_FILE:
    case GHW_FILE:
    case VCD_FILE:
    case VCD_RECODER_FILE: /* do nothing */ break;
@@ -1773,6 +1786,7 @@ void reload_into_new_context(void)
 			   		case LXT_FILE: lxt_main(GLOBALS->loaded_file_name); break;
 			   		case VCD_FILE: vcd_main(GLOBALS->loaded_file_name); break;
 					case VCD_RECODER_FILE: vcd_recoder_main(GLOBALS->loaded_file_name); break;
+					default: break;
 					}
 				
 				t = (void **)setjmp_globals->alloc2_chain;
@@ -1819,6 +1833,8 @@ void reload_into_new_context(void)
 				/* now try again, jump through recovery sequence below */
 				}
 			break;
+		default:
+			break;
  		} 
 
 	set_window_idle(NULL);
@@ -2086,6 +2102,7 @@ void free_and_destroy_page_context(void)
 #endif
         break;
  
+   case NO_FILE:
    case GHW_FILE:
    case VCD_FILE:
    case VCD_RECODER_FILE: /* do nothing */ break;
