@@ -176,7 +176,7 @@ main (int argc, char **argv)
 		case ghw_res_snapshot:
 		case ghw_res_cycle:
 		  if (flag_disp_time)
-		    printf ("Time is %lld fs\n", hp->snap_time);
+		    printf ("Time is "GHWLLD" fs\n", hp->snap_time);
 		  if (flag_disp_signals)
 		    ghw_disp_values (hp);
 		  break;
@@ -202,8 +202,11 @@ main (int argc, char **argv)
 }
 
 /*
- * $Id: ghwdump.c,v 1.1.1.1 2007/05/30 04:28:15 gtkwave Exp $
+ * $Id: ghwdump.c,v 1.2 2008/07/01 18:51:07 gtkwave Exp $
  * $Log: ghwdump.c,v $
+ * Revision 1.2  2008/07/01 18:51:07  gtkwave
+ * compiler warning fixes for amd64
+ *
  * Revision 1.1.1.1  2007/05/30 04:28:15  gtkwave
  * Imported sources
  *
