@@ -74,7 +74,11 @@ typedef uint16_t 		vztint16_t;
 typedef uint32_t		vztint32_t;
 typedef uint64_t	 	vztint64_t;
 #ifndef __MINGW32__
-#define VZT_RD_LLD "%lld"
+#if __WORDSIZE == 64
+        #define VZT_RD_LLD "%ld"      
+#else
+        #define VZT_RD_LLD "%lld"      
+#endif
 #else
 #define VZT_RD_LLD "%I64d"
 #endif
@@ -269,8 +273,11 @@ char *				vzt_rd_value(struct vzt_rd_trace *lt, vztint64_t simtime, vztint32_t f
 #endif
 
 /*
- * $Id: vzt_read.h,v 1.1.1.1 2007/05/30 04:28:18 gtkwave Exp $
+ * $Id: vzt_read.h,v 1.2 2008/07/01 18:51:07 gtkwave Exp $
  * $Log: vzt_read.h,v $
+ * Revision 1.2  2008/07/01 18:51:07  gtkwave
+ * compiler warning fixes for amd64
+ *
  * Revision 1.1.1.1  2007/05/30 04:28:18  gtkwave
  * Imported sources
  *
