@@ -70,7 +70,6 @@ static void switch_page(GtkNotebook     *notebook,
 			guint            page_num,
 			gpointer         user_data) 
 {
-int i;
 char timestr[32];
 struct Global *g_old = GLOBALS;
 
@@ -199,6 +198,7 @@ WAVE_GETOPT_CPUS
 "  -S, --script=FILE          specify GUI command script file for execution\n"
 XID_GETOPT
 INTR_GETOPT
+"  -C, --comphier             use compressed hierarchy names (slower)\n"
 "  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
 "  -L, --legacy               use legacy VCD mode rather than the VCD recoder\n" 
 "  -v, --vcd                  use stdin as a VCD dumpfile\n"
@@ -252,6 +252,11 @@ return(GLOBALS->ftext_main_main_c_1);
 
 int main(int argc, char *argv[])
 {
+return(main_2(argc, argv));
+}
+
+int main_2(int argc, char *argv[])
+{
 static char *winprefix="GTKWave - ";
 static char *winstd="GTKWave (stdio) ";
 static char *vcd_autosave_name="vcd_autosave.sav";
@@ -272,7 +277,7 @@ char *scriptfile=NULL;
 FILE *wave = NULL;
 FILE *vcd_save_handle_cached = NULL;
 
-GtkWidget *main_vbox, *top_table, *whole_table;
+GtkWidget *main_vbox = NULL, *top_table = NULL, *whole_table = NULL;
 GtkWidget *menubar;
 GtkWidget *text1;
 GtkWidget *zoombuttons;
@@ -499,11 +504,12 @@ while (1)
                 {"dualid", 1, 0, 'D'},
                 {"interactive", 0, 0, 'I'},
 		{"giga", 0, 0, 'g'},
+		{"comphier", 0, 0, 'C'},
                 {"legacy", 0, 0, 'L'},  
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgL", long_options, &option_index);
+        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCL", long_options, &option_index);
 
         if (c == -1) break;     /* no more args */
 
@@ -702,6 +708,10 @@ while (1)
 			is_giga = 1;
 			break;
 
+		case 'C':
+			GLOBALS->do_hier_compress = 1;
+			break;
+
                 case '?':
 			opt_errors_encountered=1;
                         break;
@@ -1160,13 +1170,6 @@ if(GLOBALS->use_toolbutton_interface)
 				}
 			}
 	
-		if(GLOBALS->force_toolbars)
-			{
-			toolhandle=gtk_handle_box_new();
-			gtk_widget_show(toolhandle);
-			gtk_container_add(GTK_CONTAINER(toolhandle), top_table);
-			}
-
 		whole_table = gtk_table_new (256, 16, FALSE);
 	
 		tb = gtk_toolbar_new();
@@ -1175,6 +1178,13 @@ if(GLOBALS->use_toolbutton_interface)
 		gtk_toolbar_set_style(GTK_TOOLBAR(tb), GTK_TOOLBAR_ICONS);
 		tb_pos = 0;
 
+		if(GLOBALS->force_toolbars)
+			{
+			toolhandle=gtk_handle_box_new();
+			gtk_widget_show(toolhandle);
+			gtk_container_add(GTK_CONTAINER(toolhandle), top_table);
+			}
+
 		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
 	                                         GTK_STOCK_CUT,
 						 "Cut Traces",
@@ -2038,8 +2048,17 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.28 2008/04/03 16:45:06 gtkwave Exp $
+ * $Id: main.c,v 1.31 2008/07/20 01:29:36 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.31  2008/07/20 01:29:36  gtkwave
+ * added command line option --comphier
+ *
+ * Revision 1.30  2008/07/01 18:51:06  gtkwave
+ * compiler warning fixes for amd64
+ *
+ * Revision 1.29  2008/06/11 08:01:50  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.28  2008/04/03 16:45:06  gtkwave
  * removed call to time_trunc with marker setting on initialization
  *
