@@ -22,6 +22,7 @@ struct logfile_chain *next;
 char *name;
 };
 
+int main_2(int argc, char *argv[]);
 
 GtkWidget *create_text(void);
 GtkWidget *create_zoom_buttons(void);
@@ -73,8 +74,11 @@ enum FileType {
 #endif
 
 /*
- * $Id: main.h,v 1.3 2007/12/30 04:27:39 gtkwave Exp $
+ * $Id: main.h,v 1.4 2008/07/01 18:51:07 gtkwave Exp $
  * $Log: main.h,v $
+ * Revision 1.4  2008/07/01 18:51:07  gtkwave
+ * compiler warning fixes for amd64
+ *
  * Revision 1.3  2007/12/30 04:27:39  gtkwave
  * added edge buttons to main window
  *
