@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2005.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -96,6 +96,12 @@ WV_MENU_EDFROFF,
 WV_MENU_EDFAOFF,
 WV_MENU_EDFASTEP,
 WV_MENU_EDFAINTERPOL,
+WV_MENU_EDFAINTERPOL2,
+WV_MENU_EDFARSD,
+WV_MENU_EDFARAD,
+WV_MENU_RFILL0,
+WV_MENU_RFILL1,
+WV_MENU_RFILLOFF,
 WV_MENU_XLF_0,
 WV_MENU_XLF_1,
 WV_MENU_XLP_0,
@@ -184,6 +190,9 @@ WV_MENU_VZPS,
 WV_MENU_VFTP,
 WV_MENU_SEP17,
 WV_MENU_RMRKS,
+WV_MENU_SEP17A,
+WV_MENU_USECOLOR,
+WV_MENU_USEBW,
 WV_MENU_SEP18,
 WV_MENU_LXTCC2Z,
 WV_MENU_HWH,
@@ -288,11 +297,36 @@ void menu_lxt_clk_compress(GtkWidget *widget, gpointer data);
 void menu_help(GtkWidget *widget, gpointer data);
 void menu_version(GtkWidget *widget, gpointer data);
 
+/* These should eventually have error values */
+void write_save_helper(FILE *file);
+void read_save_helper(char *wname);
+
 #endif
 
 /*
- * $Id: menu.h,v 1.5 2007/09/09 20:10:30 gtkwave Exp $
+ * $Id: menu.h,v 1.12 2008/03/25 03:22:11 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.12  2008/03/25 03:22:11  gtkwave
+ * expanded zero fill to include also a one fill (for pre-inverted nets)
+ *
+ * Revision 1.11  2008/03/24 19:34:00  gtkwave
+ * added zero range fill feature
+ *
+ * Revision 1.10  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.9  2008/01/25 04:10:14  gtkwave
+ * added new resizing options to menu
+ *
+ * Revision 1.8  2008/01/23 02:05:43  gtkwave
+ * added interpolated + step mode
+ *
+ * Revision 1.7  2008/01/12 21:36:44  gtkwave
+ * added black and white vs color rendering menu options
+ *
+ * Revision 1.6  2007/09/23 18:33:55  gtkwave
+ * warnings cleanups from sun compile
+ *
  * Revision 1.5  2007/09/09 20:10:30  gtkwave
  * preliminary support for tabbed viewing of multiple waveforms
  *
