@@ -234,7 +234,7 @@ return;
 gint xd = 0, yd = 0;
 char *asciivalue = NULL;
 int nmaxlen = 0, vmaxlen = 0;
-int totalmax;
+int totalmax = 0;
 int name_charlen = 0, value_charlen = 0;
 int num_info_rows = 2;
 char *flagged_name = NULL;
@@ -385,8 +385,11 @@ if(flagged_name) { free_2(flagged_name); }
 }
 
 /*
- * $Id: mouseover.c,v 1.8 2008/04/25 21:31:10 gtkwave Exp $
+ * $Id: mouseover.c,v 1.9 2008/07/01 18:51:07 gtkwave Exp $
  * $Log: mouseover.c,v $
+ * Revision 1.9  2008/07/01 18:51:07  gtkwave
+ * compiler warning fixes for amd64
+ *
  * Revision 1.8  2008/04/25 21:31:10  gtkwave
  * added missing t->shift in mouseover time calculation
  *
