@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2007.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -239,6 +239,13 @@ GLOBALS->hide_sst=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_sst_dynamic_filter(char *str)
+{
+DEBUG(printf("f_sst_dynamic_filter(\"%s\")\n",str));
+GLOBALS->do_dynamic_treefilter=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_sst_expanded(char *str)
 {
 DEBUG(printf("f_sst_expanded(\"%s\")\n",str));
@@ -432,6 +439,13 @@ GLOBALS->use_nonprop_fonts=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_use_pango_fonts(char *str)
+{
+DEBUG(printf("f_use_pango_fonts(\"%s\")\n",str));
+GLOBALS->use_pango_fonts=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_use_roundcaps(char *str)
 {
 DEBUG(printf("f_use_roundcaps(\"%s\")\n",str));
@@ -446,6 +460,22 @@ GLOBALS->use_scrollbar_only=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_use_standard_clicking(char *str)
+{
+DEBUG(printf("f_use_standard_clicking(\"%s\")\n",str));
+GLOBALS->use_standard_clicking=atoi_64(str)?1:0;
+return(0);
+}
+
+int f_use_toolbutton_interface(char *str)
+{
+DEBUG(printf("f_use_toolbutton_interface(\"%s\")\n",str));
+#ifdef WAVE_USE_GTK2
+GLOBALS->use_toolbutton_interface=atoi_64(str)?1:0;
+#endif
+return(0);
+}
+
 int f_vcd_explicit_zero_subscripts(char *str)
 {
 DEBUG(printf("f_vcd_explicit_zero_subscripts(\"%s\")\n",str));
@@ -485,6 +515,20 @@ if(GLOBALS->vlist_compression_depth>9) GLOBALS->vlist_compression_depth = 9;
 return(0);
 }
 
+int f_vlist_prepack(char *str)
+{
+DEBUG(printf("f_vlist_prepack(\"%s\")\n",str));
+GLOBALS->vlist_prepack=atoi_64(str);
+return(0);
+}
+
+int f_vlist_spill(char *str)
+{
+DEBUG(printf("f_vlist_spill(\"%s\")\n",str));
+GLOBALS->vlist_spill_to_disk=atoi_64(str);
+return(0);
+}
+
 int f_wave_scrolling(char *str)
 {
 DEBUG(printf("f_wave_scrolling(\"%s\")\n",str));
@@ -647,19 +691,25 @@ static struct rc_entry rcitems[]=
 { "show_base_symbols", f_show_base_symbols },
 { "show_grid", f_show_grid },
 { "splash_disable", f_splash_disable },
+{ "sst_dynamic_filter", f_sst_dynamic_filter },  
 { "sst_expanded", f_sst_expanded },
 { "use_big_fonts", f_use_big_fonts },
 { "use_frequency_display", f_use_frequency_display },
 { "use_full_precision", f_use_full_precision },
 { "use_maxtime_display", f_use_maxtime_display },
 { "use_nonprop_fonts", f_use_nonprop_fonts },
+{ "use_pango_fonts", f_use_pango_fonts },
 { "use_roundcaps", f_use_roundcaps },
 { "use_scrollbar_only", f_use_scrollbar_only },
+{ "use_standard_clicking", f_use_standard_clicking },
+{ "use_toolbutton_interface", f_use_toolbutton_interface },
 { "vcd_explicit_zero_subscripts", f_vcd_explicit_zero_subscripts },
 { "vcd_preserve_glitches", f_vcd_preserve_glitches },
 { "vcd_warning_filesize", f_vcd_warning_filesize },
 { "vector_padding", f_vector_padding },
 { "vlist_compression", f_vlist_compression },
+{ "vlist_prepack", f_vlist_prepack },
+{ "vlist_spill", f_vlist_spill },
 { "wave_scrolling", f_wave_scrolling },
 { "zoom_base", f_zoom_base },
 { "zoom_center", f_zoom_center },
@@ -677,6 +727,7 @@ f_use_frequency_display ("off");
 f_use_maxtime_display	("off");
 f_use_roundcaps		("on");
 f_use_nonprop_fonts	("on");
+f_use_pango_fonts	("on");
 f_constant_marker_update("on");
 f_show_base_symbols	("off");
 f_color_back   		("000000");
@@ -691,10 +742,10 @@ f_color_mid		("c0c000");
 f_color_value		("ffffff");
 f_color_vbox		("00ff00");
 f_color_vtrans		("00c000");
-f_color_x		("00ff00");
-f_color_xfill		("004000");
-f_color_u		("ff0000");
-f_color_ufill		("400000");
+f_color_x		("ff0000");
+f_color_xfill		("400000");
+f_color_u		("cc0000");
+f_color_ufill		("200000");
 f_color_w		("79f6f2");
 f_color_wfill		("3f817f");
 f_color_dash		("edf508");
@@ -830,8 +881,29 @@ return;
 }
 
 /*
- * $Id: rc.c,v 1.4 2007/09/11 17:17:32 gtkwave Exp $
+ * $Id: rc.c,v 1.11 2008/02/21 04:14:21 gtkwave Exp $
  * $Log: rc.c,v $
+ * Revision 1.11  2008/02/21 04:14:21  gtkwave
+ * default color for X is red now
+ *
+ * Revision 1.10  2008/02/08 15:29:19  gtkwave
+ * enabled pango font support for gtk2
+ *
+ * Revision 1.9  2008/01/08 23:03:36  gtkwave
+ * added toolbar using use_toolbutton_interface rc variable
+ *
+ * Revision 1.8  2008/01/02 18:17:26  gtkwave
+ * added standard click semantics with user_standard_clicking rc variable
+ *
+ * Revision 1.7  2007/12/29 20:19:33  gtkwave
+ * added dynamic string updates for entrybox in pattern search and sst
+ *
+ * Revision 1.6  2007/12/17 18:49:32  gtkwave
+ * added vlist_prepack rc variable which enables vlist_packer code
+ *
+ * Revision 1.5  2007/11/30 01:31:23  gtkwave
+ * added vlist memory spill to disk code + fixed vcdload status bar on > 2GB
+ *
  * Revision 1.4  2007/09/11 17:17:32  gtkwave
  * allow tab movement with context_tabposition rc variable
  *
