@@ -370,7 +370,7 @@ if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
 
 		/* printf("drop to %d of %d: '%s'\n", which, GLOBALS->traces.total, t ? t->name : "undef"); */
 		}
-	bot: 1;
+	bot: return(FALSE);
 	}
 
 	return(FALSE);
@@ -752,7 +752,7 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 			t->flags |= TR_HIGHLIGHT;
 			}
 		}
-	else
+	else if(!(t->flags & TR_HIGHLIGHT)) /* Ben Sferrazza suggested fix rather than a regular "else" */
 		{
 		GLOBALS->starting_unshifted_trace = t;
 
@@ -1177,11 +1177,13 @@ return(TRUE);
 }
 
 
+/*
 static gint popup_event (GtkWidget *widget)
 {
 do_popup_menu(widget, NULL);
 return(TRUE);
 }
+*/
 
 /***  gtkwave click routines turned on with "use_standard_clicking"=0   ***/
 /**************************************************************************/
@@ -1303,7 +1305,7 @@ static gint expose_event_local(GtkWidget *widget, GdkEventExpose *event)
 {
 gint rc;
 gint page_num = gtk_notebook_get_current_page(GTK_NOTEBOOK(GLOBALS->notebook));
-struct Global *g_old = GLOBALS;
+/* struct Global *g_old = GLOBALS; */
 
 set_GLOBALS((*GLOBALS->contexts)[page_num]);
 
@@ -1492,8 +1494,17 @@ gtk_signal_disconnect(GTK_OBJECT(GLOBALS->mainwindow), id);
 
 
 /*
- * $Id: signalwindow.c,v 1.30 2008/03/26 01:23:52 gtkwave Exp $
+ * $Id: signalwindow.c,v 1.33 2008/08/18 16:10:54 gtkwave Exp $
  * $Log: signalwindow.c,v $
+ * Revision 1.33  2008/08/18 16:10:54  gtkwave
+ * adding sticky click semantics on already selected entries
+ *
+ * Revision 1.32  2008/07/01 18:51:07  gtkwave
+ * compiler warning fixes for amd64
+ *
+ * Revision 1.31  2008/06/11 08:01:55  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.30  2008/03/26 01:23:52  gtkwave
  * reduce drag and drop visual noise
  *
