@@ -1343,7 +1343,7 @@ if(GLOBALS->mark_idx_start>0)
 		basetime=GLOBALS->named_markers[GLOBALS->mark_idx_start-1];
 	else
 		{
-		status_text(item_mark_start_strings[GLOBALS->mark_idx_start].str);
+		status_text(item_mark_start_strings[(unsigned int)GLOBALS->mark_idx_start].str);
 		status_text(" not in use.\n");
 		}
 	}
@@ -1354,7 +1354,7 @@ if(GLOBALS->mark_idx_end>0)
 		endtime=GLOBALS->named_markers[GLOBALS->mark_idx_end-1];
 	else
 		{
-		status_text(item_mark_end_strings[GLOBALS->mark_idx_end].str);
+		status_text(item_mark_end_strings[(unsigned int)GLOBALS->mark_idx_end].str);
 		status_text(" not in use.\n");
 		}
 	}
@@ -1639,8 +1639,11 @@ if(GLOBALS->timearray)
 }
 
 /*
- * $Id: strace.c,v 1.7 2007/12/31 17:11:58 gtkwave Exp $
+ * $Id: strace.c,v 1.8 2008/07/01 18:51:07 gtkwave Exp $
  * $Log: strace.c,v $
+ * Revision 1.8  2008/07/01 18:51:07  gtkwave
+ * compiler warning fixes for amd64
+ *
  * Revision 1.7  2007/12/31 17:11:58  gtkwave
  * fixed backward seek bug in pattern/edge search
  *
