@@ -38,6 +38,7 @@
 #include <config.h>
 #include "globals.h"
 #include "vcd.h"
+#include "hierpack.h"
 
 #undef VCD_BSEARCH_IS_PERFECT		/* bsearch is imperfect under linux, but OK under AIX */
 
@@ -336,7 +337,7 @@ if(GLOBALS->vcd_fsiz_vcd_c_1)
 return((int)(*(GLOBALS->vst_vcd_c_1++)));
 }
 
-static char getch() {
+static signed char getch() {
   return ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*(GLOBALS->vst_vcd_c_1++))):(getch_fetch()));
 }
 
@@ -1387,14 +1388,28 @@ for(;;)
 			else
 			if((v->msi>v->lsi)&&((v->msi-v->lsi+1)!=v->size))
 				{
-				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) goto err;
-				v->size=v->msi-v->lsi+1;
+                                if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER))
+                                        {
+                                        v->msi = v->size-1; v->lsi = 0;
+                                        /* all this formerly was goto err; */
+                                        }
+                                        else
+                                        {
+                                        v->size=v->msi-v->lsi+1;
+                                        }
 				}
 			else
 			if((v->lsi>=v->msi)&&((v->lsi-v->msi+1)!=v->size)) 
 				{
-				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) goto err;
-				v->size=v->msi-v->lsi+1;
+                                if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER))
+                                        {
+                                        v->lsi = v->size-1; v->msi = 0;
+                                        /* all this formerly was goto err; */
+                                        }
+                                        else
+                                        {
+                                        v->size=v->lsi-v->msi+1;
+                                        }
 				}
 
 			/* initial conditions */
@@ -2165,6 +2180,17 @@ if(sym_chain)
 void vcd_sortfacs(void)
 {
 int i;
+JRB ptr, lst;
+
+GLOBALS->pfx_hier_array = calloc_2(GLOBALS->hier_pfx_cnt ? GLOBALS->hier_pfx_cnt : 1, sizeof(char *));
+lst = GLOBALS->hier_pfx;
+if(lst)
+	{
+	jrb_traverse(ptr, lst)
+		{
+		GLOBALS->pfx_hier_array[ptr->val.ui] = ptr->key.s;
+		}
+	}
 
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 GLOBALS->curnode=GLOBALS->firstnode;
@@ -2207,7 +2233,19 @@ GLOBALS->facs_are_sorted=1;
 init_tree();
 for(i=0;i<GLOBALS->numfacs;i++)
 {                       
-build_tree_from_name(GLOBALS->facs[i]->name, i);
+char *n = GLOBALS->facs[i]->name;
+int was_packed;
+char *recon = hier_decompress_flagged(n, &was_packed);
+
+if(was_packed)
+	{
+	build_tree_from_name(recon, i);
+	free_2(recon);
+	}
+	else
+	{
+	build_tree_from_name(n, i);
+	}
 
 if(GLOBALS->escaped_names_found_vcd_c_1)
 	{
@@ -2423,8 +2461,23 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.4 2008/01/22 20:11:47 gtkwave Exp $
+ * $Id: vcd.c,v 1.9 2008/07/20 01:29:36 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.9  2008/07/20 01:29:36  gtkwave
+ * added command line option --comphier
+ *
+ * Revision 1.8  2008/07/18 18:46:11  gtkwave
+ * bitblasted vector relinking fix, disable hier pack in legacy+partial vcdload
+ *
+ * Revision 1.7  2008/07/18 18:22:58  gtkwave
+ * fixes for aix
+ *
+ * Revision 1.6  2008/07/18 17:27:01  gtkwave
+ * adding hierpack code
+ *
+ * Revision 1.5  2008/07/12 22:54:12  gtkwave
+ * array of wires malformed vcd dump load abort fixed
+ *
  * Revision 1.4  2008/01/22 20:11:47  gtkwave
  * track and hold experimentation
  *
