@@ -33,6 +33,7 @@
 #include <config.h>
 #include "globals.h"
 #include "vcd.h"
+#include "hierpack.h"
 
 #if !defined _MSC_VER && !defined __MINGW32__
 #include <sys/time.h>
@@ -340,7 +341,7 @@ if(!rd) return(-1);
 return((int)(*(GLOBALS->vst_vcd_partial_c_2++)));
 }
 
-static char getch() {
+static signed char getch() {
   return ((GLOBALS->vst_vcd_partial_c_2!=GLOBALS->vend_vcd_partial_c_2)?((int)(*(GLOBALS->vst_vcd_partial_c_2++))):(getch_fetch()));
 }
 
@@ -1381,14 +1382,28 @@ for(;;)
 			else
 			if((v->msi>v->lsi)&&((v->msi-v->lsi+1)!=v->size))
 				{
-				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) goto err;
-				v->size=v->msi-v->lsi+1;
+                                if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER))
+                                        {
+                                        v->msi = v->size-1; v->lsi = 0;
+                                        /* all this formerly was goto err; */
+                                        }
+                                        else
+                                        {
+                                        v->size=v->msi-v->lsi+1;
+                                        }
 				}
 			else
 			if((v->lsi>=v->msi)&&((v->lsi-v->msi+1)!=v->size)) 
 				{
-				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) goto err;
-				v->size=v->msi-v->lsi+1;
+                                if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER))
+                                        {
+                                        v->lsi = v->size-1; v->msi = 0;
+                                        /* all this formerly was goto err; */
+                                        }
+                                        else
+                                        {
+                                        v->size=v->lsi-v->msi+1;
+                                        }
 				}
 
 			/* initial conditions */
@@ -2365,8 +2380,20 @@ gtkwave_gtk_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.3 2007/09/11 02:12:50 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.7 2008/07/18 18:46:11 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.7  2008/07/18 18:46:11  gtkwave
+ * bitblasted vector relinking fix, disable hier pack in legacy+partial vcdload
+ *
+ * Revision 1.6  2008/07/18 18:23:06  gtkwave
+ * fixes for aix
+ *
+ * Revision 1.5  2008/07/18 17:27:01  gtkwave
+ * adding hierpack code
+ *
+ * Revision 1.4  2008/07/12 22:54:12  gtkwave
+ * array of wires malformed vcd dump load abort fixed
+ *
  * Revision 1.3  2007/09/11 02:12:50  gtkwave
  * context locking in busy spinloops (gtk_main_iteration() calls)
  *
