@@ -36,6 +36,7 @@
 #include "vcd.h"
 #include "vlist.h"
 #include "lx2.h"
+#include "hierpack.h"
 
 /**/
 
@@ -519,7 +520,7 @@ if(GLOBALS->vcd_fsiz_vcd_recoder_c_2)
 return((int)(*(GLOBALS->vst_vcd_recoder_c_3++)));
 }
 
-static char getch() {
+static signed char getch() {
   return ((GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*(GLOBALS->vst_vcd_recoder_c_3++))):(getch_fetch()));
 }
 
@@ -1248,7 +1249,7 @@ for(;;)
 
                                 if(GLOBALS->pv_vcd_recoder_c_3)
                                         { 
-                                        if(!strcmp(GLOBALS->pv_vcd_recoder_c_3->name,v->name))
+                                        if(!strcmp(GLOBALS->prev_hier_uncompressed_name,v->name))
                                                 {
                                                 GLOBALS->pv_vcd_recoder_c_3->chain=v;
                                                 v->root=GLOBALS->rootv_vcd_recoder_c_3;
@@ -1258,12 +1259,16 @@ for(;;)
                                                 {
                                                 GLOBALS->rootv_vcd_recoder_c_3=v;
                                                 }
+
+					free_2(GLOBALS->prev_hier_uncompressed_name);
                                         }
 					else
 					{
 					GLOBALS->rootv_vcd_recoder_c_3=v;
 					}
+
                                 GLOBALS->pv_vcd_recoder_c_3=v;
+				GLOBALS->prev_hier_uncompressed_name;
 				}
 				else	/* regular vcd var, not an evcd port var */
 				{
@@ -1327,7 +1332,7 @@ for(;;)
 
                                 if(GLOBALS->pv_vcd_recoder_c_3)
                                         { 
-                                        if(!strcmp(GLOBALS->pv_vcd_recoder_c_3->name,v->name))
+                                        if(!strcmp(GLOBALS->prev_hier_uncompressed_name,v->name))
                                                 {
                                                 GLOBALS->pv_vcd_recoder_c_3->chain=v;
                                                 v->root=GLOBALS->rootv_vcd_recoder_c_3;
@@ -1337,13 +1342,16 @@ for(;;)
                                                 {
                                                 GLOBALS->rootv_vcd_recoder_c_3=v;
                                                 }
+
+					free_2(GLOBALS->prev_hier_uncompressed_name);
                                         }
 					else
 					{
 					GLOBALS->rootv_vcd_recoder_c_3=v;
 					}
                                 GLOBALS->pv_vcd_recoder_c_3=v;
-				
+				GLOBALS->prev_hier_uncompressed_name = strdup_2(v->name);
+
 				vtok=get_vartoken(1);
 				if(vtok==V_END) goto dumpv;
 				if(vtok!=V_LB) goto err;
@@ -1390,14 +1398,28 @@ for(;;)
 			else
 			if((v->msi>v->lsi)&&((v->msi-v->lsi+1)!=v->size))
 				{
-				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) goto err;
-				v->size=v->msi-v->lsi+1;
+				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) 
+					{
+					v->msi = v->size-1; v->lsi = 0;
+					/* all this formerly was goto err; */
+					}
+					else
+					{
+					v->size=v->msi-v->lsi+1;
+					}
 				}
 			else
 			if((v->lsi>=v->msi)&&((v->lsi-v->msi+1)!=v->size)) 
 				{
-				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) goto err;
-				v->size=v->msi-v->lsi+1;
+				if((v->vartype!=V_EVENT)&&(v->vartype!=V_PARAMETER)) 
+					{
+					v->lsi = v->size-1; v->msi = 0;
+					/* all this formerly was goto err; */
+					}
+					else
+					{
+					v->size=v->lsi-v->msi+1;
+					}
 				}
 
 			/* initial conditions */
@@ -1464,11 +1486,19 @@ for(;;)
 					fprintf(stderr, "Near byte %d, $VAR parse error encountered\n", (int)(GLOBALS->vcdbyteno_vcd_recoder_c_3+(GLOBALS->vst_vcd_recoder_c_3-GLOBALS->vcdbuf_vcd_recoder_c_3)));
 					}
 				if(v->id) free_2(v->id);
-				free_2(v);
+				free_2(v); v=NULL;
 				GLOBALS->pv_vcd_recoder_c_3 = NULL;
 				}
 
 			bail:
+			if((v) && (GLOBALS->do_hier_compress))
+				{
+				char *old_name = v->name;
+				int was_packed;
+				v->name = hier_compress(v->name, HIERPACK_ADD, &was_packed);
+				if(was_packed) free_2(old_name);
+				}
+
 			if(vtok!=V_END) sync_end(NULL);
 			break;
 			}
@@ -1576,6 +1606,10 @@ for(;;)
 				{
 				GLOBALS->blackout_regions->bend = GLOBALS->current_time_vcd_recoder_c_3;
 				}
+
+			GLOBALS->pv_vcd_recoder_c_3 = NULL;
+			if(GLOBALS->prev_hier_uncompressed_name) { free_2(GLOBALS->prev_hier_uncompressed_name); GLOBALS->prev_hier_uncompressed_name = NULL; }
+			
 			return;
 		default:
 			DEBUG(fprintf(stderr,"UNKNOWN TOKEN\n"));
@@ -2295,14 +2329,14 @@ int arr_pos;
 unsigned int accum;
 unsigned char ch;
 double *d;
-unsigned char *depacked;
+unsigned char *depacked = NULL;
 
 if(!v) return;
 vlist_uncompress(&v);
 
 if(GLOBALS->vlist_prepack)
 	{
-	depacked = vlist_packer_decompress(v, &list_size);
+	depacked = vlist_packer_decompress(v, (unsigned int *)&list_size);
 	vlist_destroy(v);
 	}
 	else
@@ -2407,6 +2441,12 @@ if(vlist_type == '0') /* single bit */
 		time_idx += delta;
 
 		curtime_pnt = vlist_locate(GLOBALS->time_vlist_vcd_recoder_c_1, time_idx ? time_idx-1 : 0);
+		if(!curtime_pnt)
+			{
+			fprintf(stderr, "GTKWAVE | malformed bitwise signal data for '%s' after time_idx = %d\n", 
+				np->nname, time_idx - delta);
+			exit(255);
+			}
 
 		if(vartype != V_EVENT)
 			{
@@ -2460,6 +2500,12 @@ else if(vlist_type == 'B') /* bit vector, port type was converted to bit vector
 		time_idx += delta;
 
 		curtime_pnt = vlist_locate(GLOBALS->time_vlist_vcd_recoder_c_1,  time_idx ? time_idx-1 : 0);
+		if(!curtime_pnt)
+			{
+			fprintf(stderr, "GTKWAVE | malformed 'b' signal data for '%s' after time_idx = %d\n", 
+				np->nname, time_idx - delta);
+			exit(255);
+			}
 
 		dst_len = 0;
 		for(;;)
@@ -2541,6 +2587,12 @@ else if(vlist_type == 'R') /* real */
 		time_idx += delta;
 
 		curtime_pnt = vlist_locate(GLOBALS->time_vlist_vcd_recoder_c_1,  time_idx ? time_idx-1 : 0);
+		if(!curtime_pnt)
+			{
+			fprintf(stderr, "GTKWAVE | malformed 'r' signal data for '%s' after time_idx = %d\n", 
+				np->nname, time_idx - delta);
+			exit(255);
+			}
 
 		dst_len = 0;
 		do
@@ -2596,6 +2648,12 @@ else if(vlist_type == 'S') /* string */
 		time_idx += delta;
 
 		curtime_pnt = vlist_locate(GLOBALS->time_vlist_vcd_recoder_c_1,  time_idx ? time_idx-1 : 0);
+		if(!curtime_pnt)
+			{
+			fprintf(stderr, "GTKWAVE | malformed 's' signal data for '%s' after time_idx = %d\n", 
+				np->nname, time_idx - delta);
+			exit(255);
+			}
 
 		dst_len = 0;
 		do
@@ -2631,7 +2689,7 @@ else if(vlist_type == '!') /* error in loading */
 
 		if(GLOBALS->vlist_prepack)
 			{
-			vlist_packer_decompress_destroy(depacked);
+			vlist_packer_decompress_destroy((char *)depacked);
 			}
 			else
 			{
@@ -2650,7 +2708,7 @@ else if(vlist_type == '!') /* error in loading */
 
 if(GLOBALS->vlist_prepack)
 	{
-	vlist_packer_decompress_destroy(depacked);
+	vlist_packer_decompress_destroy((char *)depacked);
 	}
 	else
 	{
@@ -2660,8 +2718,26 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.8 2007/12/24 19:56:03 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.14 2008/07/18 18:46:11 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.14  2008/07/18 18:46:11  gtkwave
+ * bitblasted vector relinking fix, disable hier pack in legacy+partial vcdload
+ *
+ * Revision 1.13  2008/07/18 18:23:07  gtkwave
+ * fixes for aix
+ *
+ * Revision 1.12  2008/07/18 17:27:01  gtkwave
+ * adding hierpack code
+ *
+ * Revision 1.11  2008/07/12 22:54:12  gtkwave
+ * array of wires malformed vcd dump load abort fixed
+ *
+ * Revision 1.10  2008/07/11 07:02:54  gtkwave
+ * recoder fix for malformed files
+ *
+ * Revision 1.9  2008/06/11 08:01:55  gtkwave
+ * gcc 4.3.x compiler warning fixes
+ *
  * Revision 1.8  2007/12/24 19:56:03  gtkwave
  * preparing for 3.1.2 version bump
  *
